@@ -174,7 +174,6 @@ process_line (char     *line,
 
 	fdata->name = g_strdup (file_name_from_path (fdata->full_path));
 	fdata->path = remove_level_from_path (fdata->full_path);
-	fdata->type = gnome_vfs_mime_type_from_name_or_default (fdata->name, GNOME_VFS_MIME_TYPE_UNKNOWN);
 
 	if (*fdata->name == 0)
 		file_data_free (fdata);
@@ -239,7 +238,8 @@ begin_tar_command (FRCommand *comm)
 
 
 static void
-fr_command_tar_list (FRCommand *comm)
+fr_command_tar_list (FRCommand  *comm,
+		     const char *password)
 {
 	fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
 				      process_line,
@@ -644,7 +644,7 @@ get_temp_name (FRCommandTar *c_tar,
 		char *tmp_file_name;
 		g_free (temp_name);
 		g_free (uncomp_temp_name);
-		tmp_file_name = g_strdup_printf ("fr.%d.%d.%s", 
+		tmp_file_name = g_strdup_printf (".fr.%d.%d.%s", 
 						 getpid (), 
 						 count++, 
 						 filename);
