@@ -197,7 +197,6 @@ list__process_line (char     *line,
 
 	fdata->name = g_strdup (file_name_from_path (fdata->full_path));
 	fdata->path = remove_level_from_path (fdata->full_path);
-	fdata->type = gnome_vfs_mime_type_from_name_or_default (fdata->name, GNOME_VFS_MIME_TYPE_UNKNOWN);
 
 	if (*fdata->name == 0)
 		file_data_free (fdata);
@@ -240,7 +239,8 @@ add_password_arg (FRCommand     *comm,
 
 
 static void
-fr_command_zip_list (FRCommand *comm)
+fr_command_zip_list (FRCommand  *comm,
+		     const char *password)
 {
 	FR_COMMAND_ZIP (comm)->is_empty = FALSE;
 
