@@ -30,6 +30,7 @@
 
 #include "file-data.h"
 #include "file-utils.h"
+#include "glib-utils.h"
 #include "fr-command.h"
 #include "fr-command-zoo.h"
 
@@ -190,7 +191,7 @@ process_zoo_line (char     *line,
 
 	fdata = file_data_new ();
 
-	fdata->size = atol (fields[0]);
+	fdata->size = g_ascii_strtoull (fields[0], NULL, 10);
 	fdata->modified = mktime_from_string_zoo (fields[1],
 						  fields[2],
 						  fields[3],
@@ -210,7 +211,6 @@ process_zoo_line (char     *line,
 
 	fdata->name = g_strdup (file_name_from_path (fdata->full_path));
 	fdata->path = remove_level_from_path (fdata->full_path);
-	fdata->type = gnome_vfs_mime_type_from_name_or_default (fdata->name, GNOME_VFS_MIME_TYPE_UNKNOWN);
 
 	if (*fdata->name == 0)
 		file_data_free (fdata);
@@ -220,7 +220,8 @@ process_zoo_line (char     *line,
 
 
 static void
-fr_command_zoo_list (FRCommand *zoo_comm)
+fr_command_zoo_list (FRCommand  *zoo_comm,
+		     const char *password)
 {
 	fr_process_set_out_line_func (FR_COMMAND (zoo_comm)->process,
 				      process_zoo_line,
@@ -344,6 +345,8 @@ fr_command_zoo_class_init (FRCommandZooClass *class)
 static void 
 fr_command_zoo_init (FRCommand *comm)
 {
+	comm->file_type = FR_FILE_TYPE_ZOO;
+
 	comm->propAddCanUpdate             = TRUE;
 	comm->propAddCanReplace            = FALSE; 
 	comm->propExtractCanAvoidOverwrite = FALSE;
